@@ -20,7 +20,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! librsvg = "2.58.5"
+//! librsvg = "2.59.0-beta.0"
 //! cairo-rs = "0.19"
 //! gio = "0.19"   # only if you need streams
 //! ```
@@ -221,7 +221,7 @@ pub mod bench_only {
 }
 
 #[doc(hidden)]
-#[cfg(feature = "c-api")]
+#[cfg(feature = "capi")]
 pub mod c_api_only {
     pub use crate::dpi::Dpi;
     pub use crate::rsvg_log;
